
From: Colin Leroy <colin@colino.net>

This one removes the other occurences of "C"; fixes displayed fan speed so
that it uses the same scale than other occurences of this parameter instead
of RPM only; fixes the RPM reading of the fan so that it shows zero instead
of 82 when it is effectively stopped.

Signed-off-by: Colin Leroy <colin@colino.net>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/macintosh/therm_adt746x.c |   32 +++++++++++++++++++-----------
 1 files changed, 21 insertions(+), 11 deletions(-)

diff -puN drivers/macintosh/therm_adt746x.c~therm_adt746x-various-fixes drivers/macintosh/therm_adt746x.c
--- 25/drivers/macintosh/therm_adt746x.c~therm_adt746x-various-fixes	2004-10-04 23:37:51.537446192 -0700
+++ 25-akpm/drivers/macintosh/therm_adt746x.c	2004-10-04 23:37:51.541445584 -0700
@@ -54,7 +54,7 @@ MODULE_DESCRIPTION("Driver for ADT746x t
 MODULE_LICENSE("GPL");
 
 MODULE_PARM(limit_adjust,"i");
-MODULE_PARM_DESC(limit_adjust,"Adjust maximum temperatures (50C cpu, 70C gpu) by N C.");
+MODULE_PARM_DESC(limit_adjust,"Adjust maximum temperatures (50 cpu, 70 gpu) by N degrees.");
 MODULE_PARM(fan_speed,"i");
 MODULE_PARM_DESC(fan_speed,"Specify fan speed (0-255) when lim < temp < lim+8 (default 128)");
 
@@ -140,7 +140,7 @@ detach_thermostat(struct i2c_adapter *ad
 	}
 		
 	printk(KERN_INFO "adt746x: Putting max temperatures back from %d, %d, %d,"
-		" to %d, %d, %d, (C)\n", 
+		" to %d, %d, %d\n",
 		th->limits[0], th->limits[1], th->limits[2],
 		th->initial_limits[0], th->initial_limits[1], th->initial_limits[2]);
 	
@@ -176,7 +176,8 @@ static int read_fan_speed(struct thermos
 	tmp[0] = read_reg(th, addr + 1);
 	
 	res = tmp[1] + (tmp[0] << 8);
-	return (90000*60)/res;
+	/* "a value of 0xffff means that the fan has stopped" */
+	return (res == 0xffff ? 0 : (90000*60)/res);
 }
 
 static void write_both_fan_speed(struct thermostat *th, int speed)
@@ -261,14 +262,14 @@ static int monitor_task(void *arg)
 				int var = temps[i] - lims[i];
 				if (var > 8) {
 					if (th->overriding[fan_number] == 0)
-						printk(KERN_INFO "adt746x: Limit exceeded by %dC, overriding specified fan speed for %s.\n",
+						printk(KERN_INFO "adt746x: Limit exceeded by %d, overriding specified fan speed for %s.\n",
 							var, fan_number?"GPU":"CPU");
 					th->overriding[fan_number] = 1;
 					write_fan_speed(th, 255, fan_number);
 					started = 1;
 				} else if ((!th->overriding[fan_number] || var < 6) && var > 0) {
 					if (th->overriding[fan_number] == 1)
-						printk(KERN_INFO "adt746x: Limit exceeded by %dC, setting speed to specified for %s.\n",
+						printk(KERN_INFO "adt746x: Limit exceeded by %d, setting speed to specified for %s.\n",
 							var, fan_number?"GPU":"CPU");					
 					th->overriding[fan_number] = 0;
 					write_fan_speed(th, fan_speed, fan_number);
@@ -299,8 +300,8 @@ static int monitor_task(void *arg)
 		||  temps[1] != th->cached_temp[1]
 		||  temps[2] != th->cached_temp[2]) {
 			printk(KERN_INFO "adt746x: Temperature infos:"
-					 " thermostats: %d,%d,%d C;"
-					 " limits: %d,%d,%d C;"
+					 " thermostats: %d,%d,%d;"
+					 " limits: %d,%d,%d;"
 					 " fan speed: %d RPM\n",
 				temps[0], temps[1], temps[2],
 				lims[0],  lims[1],  lims[2],
@@ -370,7 +371,7 @@ attach_one_thermostat(struct i2c_adapter
 	}
 	
 	printk(KERN_INFO "adt746x: Lowering max temperatures from %d, %d, %d"
-		" to %d, %d, %d (C)\n", 
+		" to %d, %d, %d\n",
 		th->initial_limits[0], th->initial_limits[1], th->initial_limits[2], 
 		th->limits[0], th->limits[1], th->limits[2]);
 
@@ -416,6 +417,15 @@ static ssize_t show_##name(struct device
 	return sprintf(buf, "%d\n", data);			\
 }
 
+#define BUILD_SHOW_FUNC_FAN(name, data)				\
+static ssize_t show_##name(struct device *dev, char *buf)       \
+{								\
+	return sprintf(buf, "%d (%d rpm)\n", 			\
+		thermostat->last_speed[data],			\
+		read_fan_speed(thermostat, FAN_SPEED[data])	\
+		);						\
+}
+
 #define BUILD_STORE_FUNC_DEG(name, data)			\
 static ssize_t store_##name(struct device *dev, const char *buf, size_t n) \
 {								\
@@ -436,7 +446,7 @@ static ssize_t store_##name(struct devic
 	val = simple_strtoul(buf, NULL, 10);			\
 	if (val < 0 || val > 255)				\
 		return -EINVAL;					\
-	printk(KERN_INFO "Setting fan speed to %d\n", val);	\
+	printk(KERN_INFO "Setting specified fan speed to %d\n", val);	\
 	data = val;						\
 	return n;						\
 }
@@ -447,8 +457,8 @@ BUILD_SHOW_FUNC_INT(cpu_limit,		 thermos
 BUILD_SHOW_FUNC_INT(gpu_limit,		 thermostat->limits[2])
 
 BUILD_SHOW_FUNC_INT(specified_fan_speed, fan_speed)
-BUILD_SHOW_FUNC_INT(cpu_fan_speed,	 (read_fan_speed(thermostat, FAN_SPEED[0])))
-BUILD_SHOW_FUNC_INT(gpu_fan_speed,	 (read_fan_speed(thermostat, FAN_SPEED[1])))
+BUILD_SHOW_FUNC_FAN(cpu_fan_speed,	 0)
+BUILD_SHOW_FUNC_FAN(gpu_fan_speed,	 1)
 
 BUILD_STORE_FUNC_INT(specified_fan_speed,fan_speed)
 BUILD_SHOW_FUNC_INT(limit_adjust,	 limit_adjust)
_
